summaryrefslogtreecommitdiff
path: root/comphelper/source/streaming
diff options
context:
space:
mode:
authorThomas Arnhold <thomas@arnhold.org>2014-08-20 21:30:16 +0200
committerThomas Arnhold <thomas@arnhold.org>2014-08-21 09:03:18 +0200
commit007099ea3283bedfb0fe9a4c10f7331f8fc8bb73 (patch)
tree8c6dd1a512a8aaea6e46e70e04fe8d618384ef64 /comphelper/source/streaming
parent8fd3b0945607816fc7a73cec4eeb5c045bc2a450 (diff)
comphelper: staruno -> css::uno
Change-Id: I21991280c5b7e4c6d0c200f4489c89a9f4fbc385
Diffstat (limited to 'comphelper/source/streaming')
-rw-r--r--comphelper/source/streaming/basicio.cxx32
-rw-r--r--comphelper/source/streaming/oslfile2streamwrap.cxx48
-rw-r--r--comphelper/source/streaming/streamsection.cxx6
3 files changed, 43 insertions, 43 deletions
diff --git a/comphelper/source/streaming/basicio.cxx b/comphelper/source/streaming/basicio.cxx
index 30e3fa704598..d81ec90c79a9 100644
--- a/comphelper/source/streaming/basicio.cxx
+++ b/comphelper/source/streaming/basicio.cxx
@@ -25,8 +25,8 @@ namespace comphelper
-const staruno::Reference<stario::XObjectOutputStream>& operator << (
- const staruno::Reference<stario::XObjectOutputStream>& _rxOutStream,
+const css::uno::Reference<stario::XObjectOutputStream>& operator << (
+ const css::uno::Reference<stario::XObjectOutputStream>& _rxOutStream,
const starawt::FontDescriptor& _rFont)
{
_rxOutStream->writeUTF( _rFont.Name );
@@ -50,8 +50,8 @@ const staruno::Reference<stario::XObjectOutputStream>& operator << (
// FontDescriptor
-const staruno::Reference<stario::XObjectInputStream>& operator >> (
- const staruno::Reference<stario::XObjectInputStream>& _rxInStream,
+const css::uno::Reference<stario::XObjectInputStream>& operator >> (
+ const css::uno::Reference<stario::XObjectInputStream>& _rxInStream,
starawt::FontDescriptor& _rFont)
{
// schreiben des Fontdescriptors
@@ -75,84 +75,84 @@ const staruno::Reference<stario::XObjectInputStream>& operator >> (
}
-const staruno::Reference<stario::XObjectInputStream>& operator >> (const staruno::Reference<stario::XObjectInputStream>& _rxInStream, bool& _rVal)
+const css::uno::Reference<stario::XObjectInputStream>& operator >> (const css::uno::Reference<stario::XObjectInputStream>& _rxInStream, bool& _rVal)
{
_rVal = _rxInStream->readBoolean();
return _rxInStream;
}
-const staruno::Reference<stario::XObjectOutputStream>& operator << (const staruno::Reference<stario::XObjectOutputStream>& _rxOutStream, bool _bVal)
+const css::uno::Reference<stario::XObjectOutputStream>& operator << (const css::uno::Reference<stario::XObjectOutputStream>& _rxOutStream, bool _bVal)
{
_rxOutStream->writeBoolean(_bVal);
return _rxOutStream;
}
-const staruno::Reference<stario::XObjectInputStream>& operator >> (const staruno::Reference<stario::XObjectInputStream>& _rxInStream, OUString& rStr)
+const css::uno::Reference<stario::XObjectInputStream>& operator >> (const css::uno::Reference<stario::XObjectInputStream>& _rxInStream, OUString& rStr)
{
rStr = _rxInStream->readUTF();
return _rxInStream;
}
-const staruno::Reference<stario::XObjectOutputStream>& operator << (const staruno::Reference<stario::XObjectOutputStream>& _rxOutStream, const OUString& rStr)
+const css::uno::Reference<stario::XObjectOutputStream>& operator << (const css::uno::Reference<stario::XObjectOutputStream>& _rxOutStream, const OUString& rStr)
{
_rxOutStream->writeUTF(rStr);
return _rxOutStream;
}
-const staruno::Reference<stario::XObjectInputStream>& operator >> (const staruno::Reference<stario::XObjectInputStream>& _rxInStream, sal_Int16& _rValue)
+const css::uno::Reference<stario::XObjectInputStream>& operator >> (const css::uno::Reference<stario::XObjectInputStream>& _rxInStream, sal_Int16& _rValue)
{
_rValue = _rxInStream->readShort();
return _rxInStream;
}
-const staruno::Reference<stario::XObjectOutputStream>& operator << (const staruno::Reference<stario::XObjectOutputStream>& _rxOutStream, sal_Int16 _nValue)
+const css::uno::Reference<stario::XObjectOutputStream>& operator << (const css::uno::Reference<stario::XObjectOutputStream>& _rxOutStream, sal_Int16 _nValue)
{
_rxOutStream->writeShort(_nValue);
return _rxOutStream;
}
-const staruno::Reference<stario::XObjectInputStream>& operator >> (const staruno::Reference<stario::XObjectInputStream>& _rxInStream, sal_uInt16& _rValue)
+const css::uno::Reference<stario::XObjectInputStream>& operator >> (const css::uno::Reference<stario::XObjectInputStream>& _rxInStream, sal_uInt16& _rValue)
{
_rValue = _rxInStream->readShort();
return _rxInStream;
}
-const staruno::Reference<stario::XObjectOutputStream>& operator << (const staruno::Reference<stario::XObjectOutputStream>& _rxOutStream, sal_uInt16 _nValue)
+const css::uno::Reference<stario::XObjectOutputStream>& operator << (const css::uno::Reference<stario::XObjectOutputStream>& _rxOutStream, sal_uInt16 _nValue)
{
_rxOutStream->writeShort(_nValue);
return _rxOutStream;
}
-const staruno::Reference<stario::XObjectInputStream>& operator >> (const staruno::Reference<stario::XObjectInputStream>& _rxInStream, sal_uInt32& _rValue)
+const css::uno::Reference<stario::XObjectInputStream>& operator >> (const css::uno::Reference<stario::XObjectInputStream>& _rxInStream, sal_uInt32& _rValue)
{
_rValue = _rxInStream->readLong();
return _rxInStream;
}
-const staruno::Reference<stario::XObjectOutputStream>& operator << (const staruno::Reference<stario::XObjectOutputStream>& _rxOutStream, sal_uInt32 _nValue)
+const css::uno::Reference<stario::XObjectOutputStream>& operator << (const css::uno::Reference<stario::XObjectOutputStream>& _rxOutStream, sal_uInt32 _nValue)
{
_rxOutStream->writeLong(_nValue);
return _rxOutStream;
}
-const staruno::Reference<stario::XObjectInputStream>& operator >> (const staruno::Reference<stario::XObjectInputStream>& _rxInStream, sal_Int32& _rValue)
+const css::uno::Reference<stario::XObjectInputStream>& operator >> (const css::uno::Reference<stario::XObjectInputStream>& _rxInStream, sal_Int32& _rValue)
{
_rValue = _rxInStream->readLong();
return _rxInStream;
}
-const staruno::Reference<stario::XObjectOutputStream>& operator << (const staruno::Reference<stario::XObjectOutputStream>& _rxOutStream, sal_Int32 _nValue)
+const css::uno::Reference<stario::XObjectOutputStream>& operator << (const css::uno::Reference<stario::XObjectOutputStream>& _rxOutStream, sal_Int32 _nValue)
{
_rxOutStream->writeLong(_nValue);
return _rxOutStream;
diff --git a/comphelper/source/streaming/streamsection.cxx b/comphelper/source/streaming/streamsection.cxx
index 9cd2d01287c3..c1b2408ddca1 100644
--- a/comphelper/source/streaming/streamsection.cxx
+++ b/comphelper/source/streaming/streamsection.cxx
@@ -24,7 +24,7 @@ namespace comphelper
{
-OStreamSection::OStreamSection(const staruno::Reference< stario::XDataInputStream >& _rxInput)
+OStreamSection::OStreamSection(const css::uno::Reference< stario::XDataInputStream >& _rxInput)
:m_xMarkStream(_rxInput, ::com::sun::star::uno::UNO_QUERY)
,m_xInStream(_rxInput)
,m_nBlockStart(-1)
@@ -39,7 +39,7 @@ OStreamSection::OStreamSection(const staruno::Reference< stario::XDataInputStrea
}
-OStreamSection::OStreamSection(const staruno::Reference< stario::XDataOutputStream >& _rxOutput, sal_Int32 _nPresumedLength)
+OStreamSection::OStreamSection(const css::uno::Reference< stario::XDataOutputStream >& _rxOutput, sal_Int32 _nPresumedLength)
:m_xMarkStream(_rxOutput, ::com::sun::star::uno::UNO_QUERY)
,m_xOutStream(_rxOutput)
,m_nBlockStart(-1)
@@ -87,7 +87,7 @@ OStreamSection::~OStreamSection()
}
}
}
- catch(const staruno::Exception&)
+ catch(const css::uno::Exception&)
{
}
}
diff --git a/comphelper/source/streaming/oslfile2streamwrap.cxx b/comphelper/source/streaming/oslfile2streamwrap.cxx
index 03f169dd9b0c..1c8584ef79ab 100644
--- a/comphelper/source/streaming/oslfile2streamwrap.cxx
+++ b/comphelper/source/streaming/oslfile2streamwrap.cxx
@@ -37,14 +37,14 @@ OSLInputStreamWrapper::~OSLInputStreamWrapper()
}
-sal_Int32 SAL_CALL OSLInputStreamWrapper::readBytes(staruno::Sequence< sal_Int8 >& aData, sal_Int32 nBytesToRead)
- throw( stario::NotConnectedException, stario::BufferSizeExceededException, staruno::RuntimeException, std::exception )
+sal_Int32 SAL_CALL OSLInputStreamWrapper::readBytes(css::uno::Sequence< sal_Int8 >& aData, sal_Int32 nBytesToRead)
+ throw( stario::NotConnectedException, stario::BufferSizeExceededException, css::uno::RuntimeException, std::exception )
{
if (!m_pFile)
- throw stario::NotConnectedException(OUString(), static_cast<staruno::XWeak*>(this));
+ throw stario::NotConnectedException(OUString(), static_cast<css::uno::XWeak*>(this));
if (nBytesToRead < 0)
- throw stario::BufferSizeExceededException(OUString(),static_cast<staruno::XWeak*>(this));
+ throw stario::BufferSizeExceededException(OUString(),static_cast<css::uno::XWeak*>(this));
::osl::MutexGuard aGuard( m_aMutex );
@@ -53,9 +53,9 @@ sal_Int32 SAL_CALL OSLInputStreamWrapper::readBytes(staruno::Sequence< sal_Int8
sal_uInt64 nRead = 0;
FileBase::RC eError = m_pFile->read((void*)aData.getArray(), nBytesToRead, nRead);
if (eError != FileBase::E_None)
- throw stario::BufferSizeExceededException(OUString(),static_cast<staruno::XWeak*>(this));
+ throw stario::BufferSizeExceededException(OUString(),static_cast<css::uno::XWeak*>(this));
- // Wenn gelesene Zeichen < MaxLength, staruno::Sequence anpassen
+ // Wenn gelesene Zeichen < MaxLength, css::uno::Sequence anpassen
if (nRead < (sal_uInt32)nBytesToRead)
aData.realloc( sal::static_int_cast< sal_Int32 >(nRead) );
@@ -63,23 +63,23 @@ sal_Int32 SAL_CALL OSLInputStreamWrapper::readBytes(staruno::Sequence< sal_Int8
}
-sal_Int32 SAL_CALL OSLInputStreamWrapper::readSomeBytes(staruno::Sequence< sal_Int8 >& aData, sal_Int32 nMaxBytesToRead) throw( stario::NotConnectedException, stario::BufferSizeExceededException, staruno::RuntimeException, std::exception )
+sal_Int32 SAL_CALL OSLInputStreamWrapper::readSomeBytes(css::uno::Sequence< sal_Int8 >& aData, sal_Int32 nMaxBytesToRead) throw( stario::NotConnectedException, stario::BufferSizeExceededException, css::uno::RuntimeException, std::exception )
{
if (!m_pFile)
- throw stario::NotConnectedException(OUString(), static_cast<staruno::XWeak*>(this));
+ throw stario::NotConnectedException(OUString(), static_cast<css::uno::XWeak*>(this));
if (nMaxBytesToRead < 0)
- throw stario::BufferSizeExceededException(OUString(),static_cast<staruno::XWeak*>(this));
+ throw stario::BufferSizeExceededException(OUString(),static_cast<css::uno::XWeak*>(this));
return readBytes(aData, nMaxBytesToRead);
}
-void SAL_CALL OSLInputStreamWrapper::skipBytes(sal_Int32 nBytesToSkip) throw( stario::NotConnectedException, stario::BufferSizeExceededException, staruno::RuntimeException, std::exception )
+void SAL_CALL OSLInputStreamWrapper::skipBytes(sal_Int32 nBytesToSkip) throw( stario::NotConnectedException, stario::BufferSizeExceededException, css::uno::RuntimeException, std::exception )
{
::osl::MutexGuard aGuard( m_aMutex );
if (!m_pFile)
- throw stario::NotConnectedException(OUString(), static_cast<staruno::XWeak*>(this));
+ throw stario::NotConnectedException(OUString(), static_cast<css::uno::XWeak*>(this));
sal_uInt64 nCurrentPos;
m_pFile->getPos(nCurrentPos);
@@ -88,45 +88,45 @@ void SAL_CALL OSLInputStreamWrapper::skipBytes(sal_Int32 nBytesToSkip) throw( st
FileBase::RC eError = m_pFile->setPos(osl_Pos_Absolut, nNewPos);
if (eError != FileBase::E_None)
{
- throw stario::NotConnectedException(OUString(), static_cast<staruno::XWeak*>(this));
+ throw stario::NotConnectedException(OUString(), static_cast<css::uno::XWeak*>(this));
}
}
-sal_Int32 SAL_CALL OSLInputStreamWrapper::available() throw( stario::NotConnectedException, staruno::RuntimeException, std::exception )
+sal_Int32 SAL_CALL OSLInputStreamWrapper::available() throw( stario::NotConnectedException, css::uno::RuntimeException, std::exception )
{
::osl::MutexGuard aGuard( m_aMutex );
if (!m_pFile)
- throw stario::NotConnectedException(OUString(), static_cast<staruno::XWeak*>(this));
+ throw stario::NotConnectedException(OUString(), static_cast<css::uno::XWeak*>(this));
sal_uInt64 nPos;
FileBase::RC eError = m_pFile->getPos(nPos);
if (eError != FileBase::E_None)
- throw stario::NotConnectedException(OUString(), static_cast<staruno::XWeak*>(this));
+ throw stario::NotConnectedException(OUString(), static_cast<css::uno::XWeak*>(this));
sal_uInt64 nDummy = 0;
eError = m_pFile->setPos(osl_Pos_End, nDummy);
if (eError != FileBase::E_None)
- throw stario::NotConnectedException(OUString(),static_cast<staruno::XWeak*>(this));
+ throw stario::NotConnectedException(OUString(),static_cast<css::uno::XWeak*>(this));
sal_uInt64 nAvailable;
eError = m_pFile->getPos(nAvailable);
if (eError != FileBase::E_None)
- throw stario::NotConnectedException(OUString(),static_cast<staruno::XWeak*>(this));
+ throw stario::NotConnectedException(OUString(),static_cast<css::uno::XWeak*>(this));
nAvailable = nAvailable - nPos;
eError = m_pFile->setPos(osl_Pos_Absolut, nPos);
if (eError != FileBase::E_None)
- throw stario::NotConnectedException(OUString(),static_cast<staruno::XWeak*>(this));
+ throw stario::NotConnectedException(OUString(),static_cast<css::uno::XWeak*>(this));
return sal::static_int_cast< sal_Int32 >(
std::max(nAvailable, sal::static_int_cast< sal_uInt64 >(SAL_MAX_INT32)));
}
-void SAL_CALL OSLInputStreamWrapper::closeInput() throw( stario::NotConnectedException, staruno::RuntimeException, std::exception )
+void SAL_CALL OSLInputStreamWrapper::closeInput() throw( stario::NotConnectedException, css::uno::RuntimeException, std::exception )
{
if (!m_pFile)
- throw stario::NotConnectedException(OUString(), static_cast<staruno::XWeak*>(this));
+ throw stario::NotConnectedException(OUString(), static_cast<css::uno::XWeak*>(this));
m_pFile->close();
@@ -143,24 +143,24 @@ OSLOutputStreamWrapper::OSLOutputStreamWrapper(osl::File & _rFile):
OSLOutputStreamWrapper::~OSLOutputStreamWrapper() {}
-void SAL_CALL OSLOutputStreamWrapper::writeBytes(const staruno::Sequence< sal_Int8 >& aData) throw( stario::NotConnectedException, stario::BufferSizeExceededException, staruno::RuntimeException, std::exception )
+void SAL_CALL OSLOutputStreamWrapper::writeBytes(const css::uno::Sequence< sal_Int8 >& aData) throw( stario::NotConnectedException, stario::BufferSizeExceededException, css::uno::RuntimeException, std::exception )
{
sal_uInt64 nWritten;
FileBase::RC eError = rFile.write(aData.getConstArray(),aData.getLength(), nWritten);
if (eError != FileBase::E_None
|| nWritten != sal::static_int_cast< sal_uInt32 >(aData.getLength()))
{
- throw stario::BufferSizeExceededException(OUString(),static_cast<staruno::XWeak*>(this));
+ throw stario::BufferSizeExceededException(OUString(),static_cast<css::uno::XWeak*>(this));
}
}
-void SAL_CALL OSLOutputStreamWrapper::flush() throw( stario::NotConnectedException, stario::BufferSizeExceededException, staruno::RuntimeException, std::exception )
+void SAL_CALL OSLOutputStreamWrapper::flush() throw( stario::NotConnectedException, stario::BufferSizeExceededException, css::uno::RuntimeException, std::exception )
{
}
-void SAL_CALL OSLOutputStreamWrapper::closeOutput() throw( stario::NotConnectedException, stario::BufferSizeExceededException, staruno::RuntimeException, std::exception )
+void SAL_CALL OSLOutputStreamWrapper::closeOutput() throw( stario::NotConnectedException, stario::BufferSizeExceededException, css::uno::RuntimeException, std::exception )
{
rFile.close();
}